UnsupportedUvcCameraPlatform class final

A platform where UVC cameras are not available. Every call reports AccessStatus.unsupported or throws Unsupported.

Inheritance

Properties

events Stream<DeviceEvent>
Attach and detach events.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAccess([DeviceHandle? device]) Future<AccessReport>
Returns the current access state without showing any prompt.
override
devices() Future<List<DeviceHandle>>
UVC cameras currently attached (Android) or available (web).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(DeviceHandle device, List<UvcSize> preferred) Future<UvcCameraSession>
Opens device and starts the preview at the first size in preferred the camera supports (see selectPreviewSize).
override
openSettings() Future<bool>
Opens this app's page in the system settings.
override
requestAccess([DeviceHandle? device]) Future<AccessReport>
Requests access, which may show system dialogs.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited