checkAccess method
Returns the current access state without showing any prompt.
Implementation
@override
Future<AccessReport> checkAccess([DeviceHandle? device]) async => _report;
Returns the current access state without showing any prompt.
@override
Future<AccessReport> checkAccess([DeviceHandle? device]) async => _report;