requestAccess method
Requests access, which may show system dialogs.
On the web this must be called from a user gesture such as a tap.
Implementation
@override
Future<AccessReport> requestAccess([DeviceHandle? device]) async => _report;
Requests access, which may show system dialogs.
On the web this must be called from a user gesture such as a tap.
@override
Future<AccessReport> requestAccess([DeviceHandle? device]) async => _report;