open abstract method
Opens device and starts the preview at the first size in preferred
the camera supports (see selectPreviewSize).
Implementation
Future<UvcCameraSession> open(DeviceHandle device, List<UvcSize> preferred);
Opens device and starts the preview at the first size in preferred
the camera supports (see selectPreviewSize).
Future<UvcCameraSession> open(DeviceHandle device, List<UvcSize> preferred);